@@ -38,6 +38,9 @@
 /* Support XDM-AUTH*-1 */
 #define HASXDMAUTH 1
 
+/* Add a padding for legacy nvidia drivers that support old ABI */
+#define CONFIG_LEGACY_NVIDIA_PADDING 1
+
 /* Define to 1 if you have the `reallocarray' function. */
 #define HAVE_REALLOCARRAY 1
 
@@ -58,6 +61,7 @@
 
 /* Support MIT-SHM Extension */
 #define MITSHM 1
+#define CONFIG_MITSHM 1
 
 /* Internal define for Xinerama */
 #define PANORAMIX 1
@@ -84,9 +88,6 @@
 /* Define to 1 on systems derived from System V Release 4 */
 #undef SVR4
 
-/* Support TCP socket connections */
-#define TCPCONN 1
-
 /* Support UNIX socket connections */
 #define UNIXCONN 1
 
@@ -124,7 +125,7 @@
 #define XORGSERVER 1
 
 /* Current Xorg version */
-#define XORG_VERSION_CURRENT 12500000
+#define XORG_VERSION_CURRENT 12501001
 
 /* Build Xv Extension */
 #define XvExtension 1
@@ -141,9 +142,6 @@
 /* Support Xv Extension */
 #define XV 1
 
-/* Vendor name */
-#define XVENDORNAME "XLibre"
-
 /* BSD-compliant source */
 /* #undef _BSD_SOURCE */
 
@@ -153,9 +151,6 @@
 /* X/Open-compliant source */
 /* #undef _XOPEN_SOURCE */
 
-/* Vendor web address for support */
-#define __VENDORDWEBSUPPORT__ "https://github.com/X11Libre/xserver"
-
 /* Location of configuration file */
 #define XCONFIGFILE "xorg.conf"
 
@@ -214,7 +209,4 @@
 #define XORG_API_DIX_SCREEN_HOOK_CLOSE 1
 #define XORG_API_DIX_SCREEN_HOOK_PIXMAP_DESTROY 1
 
-/* needed for os.h to prevent redefinition of timingsafe_memcmp in drivers */
-#undef HAVE_TIMINGSAFE_MEMCMP
-
 #endif /* _XORG_SERVER_H_ */
